Modular Abelian Varieties
=========================

.. toctree::
   :maxdepth: 1

   sage/modular/abvar/constructor
   sage/modular/abvar/abvar
   sage/modular/abvar/abvar_ambient_jacobian
   sage/modular/abvar/finite_subgroup
   sage/modular/abvar/torsion_subgroup
   sage/modular/abvar/cuspidal_subgroup
   sage/modular/abvar/homology
   sage/modular/abvar/homspace
   sage/modular/abvar/morphism
   sage/modular/abvar/abvar_newform
   sage/modular/abvar/lseries

.. include:: ../footer.txt
